import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;

/**
 * Filter fr die Zeilen in Log-Files.
 * Die Quell-datei wird zeilenweise gefiltert,
 * nach Filter-String enthalten in der Zeile,
 * und in die Ziel-Datei kopiert.
 * 
 * <br/>
 * <b>Author:</b> <a href="http://www.heinerkuecker.de" target="_blank">Heiner Kcker</a>
 * <br/>
 *
 * @author Heiner kcker
 */
public class LogFileFilter
{

  public static void main(String[] args)
  {
    if (args == null || args.length != 3)
    {
      System.out.println( "Aufruf mit <source-file> <filter-str> <dest-file> [/i]" );
      System.out.println( "optionaler Paramter /i for ignore case" );
      //System.exit(1);
    }
    
    final String srcFileName;
    if (args == null || args.length > 0 )
    {
      srcFileName = args[0];
    }
    else
    {
      System.out.print( "Source log file:" );
      srcFileName = readConsole();
    }
    
    String filtStr;
    if (args == null || args.length > 1 )
    {
      filtStr = args[1];
    }
    else
    {
      System.out.print( "log filter string:" );
      filtStr = readConsole();
    }

    final String dstFileName;
    if (args == null || args.length > 2 )
    {
      dstFileName = args[2];
    }
    else
    {
      dstFileName = srcFileName + ".filt";
    }

    final boolean isIgnoreCase;
    if (args == null || args.length > 3 )
    {
      isIgnoreCase = args[3].equalsIgnoreCase( "/i" );
    }
    else
    {
      System.out.print( "ignore case:");
      final String isIgnoreCaseStr = readConsole();
      isIgnoreCase = StringUtil.str2bool( isIgnoreCaseStr ) ;
    }
    if (isIgnoreCase)
    {
      filtStr = filtStr.toUpperCase();
    }

    //Log-File einlesen
    String[] lineArr = StringUtil.file2StrArr( srcFileName );
    final int srcLineCnt = lineArr.length;
    
    // Filter for enthalten in
    ArrayList list = new ArrayList( lineArr.length );
    for (int i = 0; i < lineArr.length; i++)
    {
      String line = lineArr[i];
      if (isIgnoreCase)
      {
        line = line.toUpperCase();
      }
      if ( line.indexOf( filtStr ) >= 0 )
      {
        // TODO Ignore Case
        list.add( line );
      }
    }
    lineArr = (String[]) list.toArray( new String[ list.size() ] );
    
    //Schreibe in Zieldatei
    StringUtil.strArr2file( lineArr , dstFileName );
    System.out.println( lineArr.length + " lines from " + srcLineCnt + ( isIgnoreCase ? "(ignore case)" : "" ) + " written to " + dstFileName );
  }
  
  /**
   * Read string from console.
   * 
   * @return
   */
  private static String readConsole()
  {
    InputStreamReader isr = new InputStreamReader(System.in);
    BufferedReader input = new BufferedReader(isr);
    
    String line = null;
    
    try
    {
      line = input.readLine();
    }
    catch (IOException e)
    {
      System.err.println(e.getMessage());
      e.printStackTrace();
    }
    return line;
  }
  
}
